==> qt-x11-free-3.0.3.tar.bz2: qt-x11-free-3.0.3/src/tools/qcriticalsection_p.h <==
/****************************************************************************
** $Id$
**
** Definition of QCriticalSection class
**
** Created : 
**
** Copyright (C) 2001 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
** licenses may use this file in accordance with the Qt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/qpl/ for QPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef QCRITICALSECTION_H
#define QCRITICALSECTION_H

#ifndef QT_H
#endif // QT_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of Qt Remote Control. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
//

#if defined(QT_THREAD_SUPPORT)

#if defined(Q_WS_WIN)

/*
  QCriticalSection
*/

class QCriticalSectionPrivate;

class QCriticalSection
{
public:
    QCriticalSection();
    ~QCriticalSection();
    void enter();
    void leave();

private:
    QCriticalSectionPrivate *d;
};

#endif

#endif

#endif

==> qt-x11-free-3.1.1.tar.bz2: qt-x11-free-3.1.1/src/tools/qcriticalsection_p.h <==
/****************************************************************************
** $Id: qt/qcriticalsection_p.h   3.1.1   edited Nov 7 16:55 $
**
** Definition of QCriticalSection class
**
** Copyright (C) 2001-2002 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
** licenses may use this file in accordance with the Qt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/qpl/ for QPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef QCRITICALSECTION_P_H
#define QCRITICALSECTION_P_H

#ifndef QT_H
#endif // QT_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of Qt Remote Control. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
//

#if defined(QT_THREAD_SUPPORT)

#if defined(Q_WS_WIN)

/*
  QCriticalSection
*/

class QCriticalSectionPrivate;

class QCriticalSection
{
public:
    QCriticalSection();
    ~QCriticalSection();
    void enter();
    void leave();

private:
    QCriticalSectionPrivate *d;
};

#endif

#endif

#endif
